import * as _backstage_plugin_scaffolder_node from '@backstage/plugin-scaffolder-node';
import * as _backstage_types from '@backstage/types';
import { ScmIntegrationRegistry } from '@backstage/integration';
import { Config } from '@backstage/config';
import * as _backstage_backend_plugin_api from '@backstage/backend-plugin-api';

/**
 * Creates a new action that initializes a git repository of the content in the workspace
 * and publishes it to GitLab.
 *
 * @public
 */
declare function createPublishGitlabAction(options: {
    integrations: ScmIntegrationRegistry;
    config: Config;
}): _backstage_plugin_scaffolder_node.TemplateAction<{
    repoUrl: string;
    defaultBranch?: string | undefined;
    /** @deprecated in favour of settings.visibility field */
    repoVisibility?: "internal" | "private" | "public" | undefined;
    sourcePath?: string | undefined;
    token?: string | undefined;
    gitCommitMessage?: string | undefined;
    gitAuthorName?: string | undefined;
    gitAuthorEmail?: string | undefined;
    setUserAsOwner?: boolean | undefined;
    /** @deprecated in favour of settings.topics field */
    topics?: string[] | undefined;
    settings?: {
        path?: string | undefined;
        auto_devops_enabled?: boolean | undefined;
        ci_config_path?: string | undefined;
        description?: string | undefined;
        merge_method?: "merge" | "ff" | "rebase_merge" | undefined;
        squash_option?: "always" | "never" | "default_on" | "default_off" | undefined;
        topics?: string[] | undefined;
        visibility?: "internal" | "private" | "public" | undefined;
        only_allow_merge_if_all_discussions_are_resolved?: boolean | undefined;
        only_allow_merge_if_pipeline_succeeds?: boolean | undefined;
        allow_merge_on_skipped_pipeline?: boolean | undefined;
    } | undefined;
    branches?: {
        name: string;
        protect?: boolean | undefined;
        create?: boolean | undefined;
        ref?: string | undefined;
    }[] | undefined;
    projectVariables?: {
        key: string;
        value: string;
        description?: string | undefined;
        variable_type?: string | undefined;
        protected?: boolean | undefined;
        masked?: boolean | undefined;
        raw?: boolean | undefined;
        environment_scope?: string | undefined;
    }[] | undefined;
}, _backstage_types.JsonObject>;

/**
 * Creates an `gitlab:group:ensureExists` Scaffolder action.
 *
 * @public
 */
declare const createGitlabGroupEnsureExistsAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    path: string[];
    repoUrl: string;
    token?: string | undefined;
}, {
    groupId?: number | undefined;
}>;

/**
 * Gitlab issue types as specified by gitlab api
 *
 * @public
 */
declare enum IssueType {
    ISSUE = "issue",
    INCIDENT = "incident",
    TEST = "test_case",
    TASK = "task"
}
/**
 * Gitlab issue state events for modifications
 *
 * @public
 */
declare enum IssueStateEvent {
    CLOSE = "close",
    REOPEN = "reopen"
}

/**
 * Creates a `gitlab:issues:create` Scaffolder action.
 *
 * @param options - Templating configuration.
 * @public
 */
declare const createGitlabIssueAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    title: string;
    repoUrl: string;
    projectId: number;
    labels?: string | undefined;
    description?: string | undefined;
    weight?: number | undefined;
    token?: string | undefined;
    assignees?: number[] | undefined;
    createdAt?: string | undefined;
    confidential?: boolean | undefined;
    milestoneId?: number | undefined;
    epicId?: number | undefined;
    dueDate?: string | undefined;
    discussionToResolve?: string | undefined;
    issueType?: IssueType | undefined;
    mergeRequestToResolveDiscussionsOf?: number | undefined;
}, {
    issueUrl: string;
    issueId: number;
    issueIid: number;
}>;

/**
 * Creates a `gitlab:issue:edit` Scaffolder action.
 *
 * @param options - Templating configuration.
 * @public
 */
declare const editGitlabIssueAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    repoUrl: string;
    projectId: number;
    issueIid: number;
    title?: string | undefined;
    labels?: string | undefined;
    description?: string | undefined;
    weight?: number | undefined;
    token?: string | undefined;
    assignees?: number[] | undefined;
    addLabels?: string | undefined;
    confidential?: boolean | undefined;
    milestoneId?: number | undefined;
    removeLabels?: string | undefined;
    stateEvent?: IssueStateEvent | undefined;
    discussionLocked?: boolean | undefined;
    epicId?: number | undefined;
    dueDate?: string | undefined;
    updatedAt?: string | undefined;
    issueType?: IssueType | undefined;
}, {
    state: string;
    title: string;
    projectId: number;
    updatedAt: string;
    issueUrl: string;
    issueId: number;
    issueIid: number;
}>;

/**
 * Create a new action that creates a gitlab merge request.
 *
 * @public
 */
declare const createPublishGitlabMergeRequestAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    repoUrl: string;
    title: string;
    description: string;
    branchName: string;
    targetBranchName?: string | undefined;
    sourcePath?: string | undefined;
    targetPath?: string | undefined;
    token?: string | undefined;
    commitAction?: "auto" | "update" | "delete" | "create" | "skip" | undefined;
    /** @deprecated projectID passed as query parameters in the repoUrl */
    projectid?: string | undefined;
    removeSourceBranch?: boolean | undefined;
    assignee?: string | undefined;
}, _backstage_types.JsonObject>;

/**
 * Creates a `gitlab:pipeline:trigger` Scaffolder action.
 *
 * @param options - Templating configuration.
 * @public
 */
declare const createTriggerGitlabPipelineAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    branch: string;
    repoUrl: string;
    projectId: number;
    tokenDescription: string;
    token?: string | undefined;
    variables?: Record<string, string> | undefined;
}, {
    pipelineUrl: string;
}>;

/**
 * Creates a `gitlab:projectAccessToken:create` Scaffolder action.
 *
 * @param options - Templating configuration.
 * @public
 */
declare const createGitlabProjectAccessTokenAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    repoUrl: string;
    projectId: string | number;
    name?: string | undefined;
    token?: string | undefined;
    scopes?: string[] | undefined;
    expiresAt?: string | undefined;
    accessLevel?: number | undefined;
}, {
    access_token: string;
}>;

/**
 * Creates a `gitlab:projectDeployToken:create` Scaffolder action.
 *
 * @param options - Templating configuration.
 * @public
 */
declare const createGitlabProjectDeployTokenAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    name: string;
    scopes: string[];
    repoUrl: string;
    projectId: string | number;
    username?: string | undefined;
    token?: string | undefined;
}, {
    user: string;
    deploy_token: string;
}>;

/**
 * Creates a `gitlab:projectVariable:create` Scaffolder action.
 *
 * @param options - Templating configuration.
 * @public
 */
declare const createGitlabProjectVariableAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    key: string;
    value: string;
    repoUrl: string;
    projectId: string | number;
    variableType: string;
    raw?: boolean | undefined;
    token?: string | undefined;
    masked?: boolean | undefined;
    environmentScope?: string | undefined;
    variableProtected?: boolean | undefined;
}, _backstage_types.JsonObject>;

/**
 * Create a new action that commits into a gitlab repository.
 *
 * @public
 */
declare const createGitlabRepoPushAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    repoUrl: string;
    branchName: string;
    commitMessage: string;
    sourcePath?: string | undefined;
    targetPath?: string | undefined;
    token?: string | undefined;
    commitAction?: "update" | "delete" | "create" | undefined;
}, _backstage_types.JsonObject>;

/**
 * @public
 * The GitLab Module for the Scaffolder Backend
 */
declare const gitlabModule: _backstage_backend_plugin_api.BackendFeature;

export { IssueStateEvent, IssueType, createGitlabGroupEnsureExistsAction, createGitlabIssueAction, createGitlabProjectAccessTokenAction, createGitlabProjectDeployTokenAction, createGitlabProjectVariableAction, createGitlabRepoPushAction, createPublishGitlabAction, createPublishGitlabMergeRequestAction, createTriggerGitlabPipelineAction, gitlabModule as default, editGitlabIssueAction };
